From akpm@osdl.org Mon Jun  6 23:10:58 2005
Message-Id: <200506070607.j5767oc1008190@shell0.pdx.osdl.net>
Subject: PCI: fix up errors after dma bursting patch and CONFIG_PCI=n
To: akpm@osdl.org, greg@kroah.com
From: akpm@osdl.org
Date: Mon, 06 Jun 2005 23:07:46 -0700


From: Andrew Morton <akpm@osdl.org>

With CONFIG_PCI=n:

In file included from include/linux/pci.h:917,
                 from lib/iomap.c:6:
include/asm/pci.h:104: warning: `enum pci_dma_burst_strategy' declared inside parameter list
include/asm/pci.h:104: warning: its scope is only this definition or declaration, which is probably not what you want.
include/asm/pci.h: In function `pci_dma_burst_advice':
include/asm/pci.h:106: dereferencing pointer to incomplete type
include/asm/pci.h:106: `PCI_DMA_BURST_INFINITY' undeclared (first use in this function)
include/asm/pci.h:106: (Each undeclared identifier is reported only once
include/asm/pci.h:106: for each function it appears in.)
make[1]: *** [lib/iomap.o] Error 1

Signed-off-by: Andrew Morton <akpm@osdl.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 include/asm-alpha/pci.h   |    2 ++
 include/asm-arm/pci.h     |    2 ++
 include/asm-frv/pci.h     |    2 ++
 include/asm-i386/pci.h    |    2 ++
 include/asm-ia64/pci.h    |    2 ++
 include/asm-mips/pci.h    |    2 ++
 include/asm-parisc/pci.h  |    2 ++
 include/asm-ppc/pci.h     |    2 ++
 include/asm-ppc64/pci.h   |    2 ++
 include/asm-sh/pci.h      |    2 ++
 include/asm-sh64/pci.h    |    2 ++
 include/asm-sparc/pci.h   |    2 ++
 include/asm-sparc64/pci.h |    2 ++
 include/asm-v850/pci.h    |    2 ++
 include/asm-x86_64/pci.h  |    2 ++
 include/linux/pci.h       |    2 ++
 16 files changed, 32 insertions(+)

--- gregkh-2.6.orig/include/asm-alpha/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-alpha/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -223,6 +223,7 @@
 	/* Nothing to do. */
 }
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -239,6 +240,7 @@
 	*strat = PCI_DMA_BURST_BOUNDARY;
 	*strategy_parameter = cacheline_size;
 }
+#endif
 
 /* TODO: integrate with include/asm-generic/pci.h ? */
 static inline int pci_get_legacy_ide_irq(struct pci_dev *dev, int channel)
--- gregkh-2.6.orig/include/asm-arm/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-arm/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -42,6 +42,7 @@
 #define pci_unmap_len(PTR, LEN_NAME)		((PTR)->LEN_NAME)
 #define pci_unmap_len_set(PTR, LEN_NAME, VAL)	(((PTR)->LEN_NAME) = (VAL))
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -49,6 +50,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 #define HAVE_PCI_MMAP
 extern int pci_mmap_page_range(struct pci_dev *dev, struct vm_area_struct *vma,
--- gregkh-2.6.orig/include/asm-frv/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-frv/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -57,6 +57,7 @@
  */
 #define PCI_DMA_BUS_IS_PHYS	(1)
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -64,6 +65,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 /*
  *	These are pretty much arbitary with the CoMEM implementation.
--- gregkh-2.6.orig/include/asm-i386/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-i386/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -99,6 +99,7 @@
 {
 }
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -106,6 +107,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 #endif /* __KERNEL__ */
 
--- gregkh-2.6.orig/include/asm-ia64/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-ia64/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -82,6 +82,7 @@
 #define sg_dma_len(sg)		((sg)->dma_length)
 #define sg_dma_address(sg)	((sg)->dma_address)
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -98,6 +99,7 @@
 	*strat = PCI_DMA_BURST_MULTIPLE;
 	*strategy_parameter = cacheline_size;
 }
+#endif
 
 #define HAVE_PCI_MMAP
 extern int pci_mmap_page_range (struct pci_dev *dev, struct vm_area_struct *vma,
--- gregkh-2.6.orig/include/asm-mips/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-mips/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -130,6 +130,7 @@
 extern void pci_dac_dma_sync_single_for_device(struct pci_dev *pdev,
 	dma64_addr_t dma_addr, size_t len, int direction);
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -137,6 +138,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 extern void pcibios_resource_to_bus(struct pci_dev *dev,
 	struct pci_bus_region *region, struct resource *res);
--- gregkh-2.6.orig/include/asm-parisc/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-parisc/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -230,6 +230,7 @@
 /* export the pci_ DMA API in terms of the dma_ one */
 #include <asm-generic/pci-dma-compat.h>
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -246,6 +247,7 @@
 	*strat = PCI_DMA_BURST_MULTIPLE;
 	*strategy_parameter = cacheline_size;
 }
+#endif
 
 extern void
 pcibios_resource_to_bus(struct pci_dev *dev, struct pci_bus_region *region,
--- gregkh-2.6.orig/include/asm-ppc64/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-ppc64/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -78,6 +78,7 @@
 	return 0;
 }
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -94,6 +95,7 @@
 	*strat = PCI_DMA_BURST_MULTIPLE;
 	*strategy_parameter = cacheline_size;
 }
+#endif
 
 extern int pci_domain_nr(struct pci_bus *bus);
 
--- gregkh-2.6.orig/include/asm-ppc/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-ppc/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -69,6 +69,7 @@
 #define pci_unmap_len(PTR, LEN_NAME)		(0)
 #define pci_unmap_len_set(PTR, LEN_NAME, VAL)	do { } while (0)
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -76,6 +77,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 /*
  * At present there are very few 32-bit PPC machines that can have
--- gregkh-2.6.orig/include/asm-sh64/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-sh64/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -86,6 +86,7 @@
 #define sg_dma_address(sg)	((sg)->dma_address)
 #define sg_dma_len(sg)		((sg)->length)
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -93,6 +94,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 /* Board-specific fixup routines. */
 extern void pcibios_fixup(void);
--- gregkh-2.6.orig/include/asm-sh/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-sh/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -96,6 +96,7 @@
 #define sg_dma_address(sg)	(virt_to_bus((sg)->dma_address))
 #define sg_dma_len(sg)		((sg)->length)
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -103,6 +104,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 /* Board-specific fixup routines. */
 extern void pcibios_fixup(void);
--- gregkh-2.6.orig/include/asm-sparc64/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-sparc64/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -220,6 +220,7 @@
 	return (dma_addr == PCI_DMA_ERROR_CODE);
 }
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -236,6 +237,7 @@
 	*strat = PCI_DMA_BURST_BOUNDARY;
 	*strategy_parameter = cacheline_size;
 }
+#endif
 
 /* Return the index of the PCI controller for device PDEV. */
 
--- gregkh-2.6.orig/include/asm-sparc/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-sparc/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -144,6 +144,7 @@
 
 #define pci_dac_dma_supported(dev, mask)	(0)
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -151,6 +152,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 static inline void pcibios_add_platform_entries(struct pci_dev *dev)
 {
--- gregkh-2.6.orig/include/asm-v850/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-v850/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -81,6 +81,7 @@
 pci_free_consistent (struct pci_dev *pdev, size_t size, void *cpu_addr,
 		     dma_addr_t dma_addr);
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -88,6 +89,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 static inline void pcibios_add_platform_entries(struct pci_dev *dev)
 {
--- gregkh-2.6.orig/include/asm-x86_64/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/asm-x86_64/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -123,6 +123,7 @@
 	flush_write_buffers();
 }
 
+#ifdef CONFIG_PCI
 static inline void pci_dma_burst_advice(struct pci_dev *pdev,
 					enum pci_dma_burst_strategy *strat,
 					unsigned long *strategy_parameter)
@@ -130,6 +131,7 @@
 	*strat = PCI_DMA_BURST_INFINITY;
 	*strategy_parameter = ~0UL;
 }
+#endif
 
 #define HAVE_PCI_MMAP
 extern int pci_mmap_page_range(struct pci_dev *dev, struct vm_area_struct *vma,
--- gregkh-2.6.orig/include/linux/pci.h	2005-06-09 22:29:35.000000000 -0700
+++ gregkh-2.6/include/linux/pci.h	2005-06-09 22:29:48.000000000 -0700
@@ -985,6 +985,8 @@
 }
 #endif
 
+#define pci_dma_burst_advice(pdev, strat, strategy_parameter) do { } while (0)
+
 #endif /* !CONFIG_PCI */
 
 /* these helpers provide future and backwards compatibility
